% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/emis_paved.R
\name{emis_paved}
\alias{emis_paved}
\title{Estimation of resuspension emissions from paved roads}
\usage{
emis_paved(veh, lkm, k, sL1, sL2, sL3, sL4, W)
}
\arguments{
\item{veh}{Numeric vector with length of elements equals to number of streets
It is an array with dimenssions number of streets x hours of day x days of week}

\item{lkm}{Length of each link}

\item{k}{K_PM30 = 3.23, K_PM15 = 0.77, K_PM10 = 0.62 and K_PM2.5 = 0.15}

\item{sL1}{Silt loading (g/m2) for roads with ADT <= 500}

\item{sL2}{Silt loading (g/m2) for roads with ADT > 500 and <= 5000}

\item{sL3}{Silt loading (g/m2) for roads with ADT > 5000 and <= 1000}

\item{sL4}{Silt loading (g/m2) for roads with ADT > 10000}

\item{W}{array of dimensions of veh. It consists in the hourly averaged
weight of traffic fleet in each road}
}
\value{
emission estimation  g/h
}
\description{
The vehicular emissions are estimated as the product of the vehicles on a
road, length of the road, emission factor from AP42 13.2.1 Paved roads.
It is assumed dry hours and anual aggregation should consider moisture factor.
It depends on Average Daily Traffic (ADT)
}
\examples{
\dontrun{
# Do not run
veh <- array(pnorm(q=c(1:100), mean=500, sd = 100),
             c(100,24,7))
W <- veh*1e+05
lkm <-  rnorm(n = 100, mean = 10, sd = 1)
sL1 <- 0.6
emi  <- emis_paved(veh = veh, lkm = lkm, k = 0.65,
                       sL1 = sL1, sL2 = sL1/4, sL3 = sL1/16, sL4 = sL1/32,
                       W = W)
}
}
\references{
EPA, 2016. Emission factor documentation for AP-42. Section
13.2.1, Paved Roads. https://www3.epa.gov/ttn/chief/ap42/ch13/final/c13s0201.pdf
}
